searchData={"items":[{"type":"module","doc":"`NLdoc.Util` implements utility functions that are used throughout the project,\nbut don't fit into any of the other modules.","title":"NLdoc.Util","ref":"NLdoc.Util.html"},{"type":"function","doc":"Returns the new value if it is not nil, otherwise returns the default value.","title":"NLdoc.Util.default/2","ref":"NLdoc.Util.html#default/2"},{"type":"function","doc":"iex> NLdoc.Util.default(nil, 1)\n    1\n    iex> NLdoc.Util.default(2, 1)\n    2","title":"Examples - NLdoc.Util.default/2","ref":"NLdoc.Util.html#default/2-examples"},{"type":"function","doc":"Encodes a map, list, keyword list, tuple or any other term into a format that can be encoded with Jason\nwithout raising an error. Also handles some special cases to make the output more readable.","title":"NLdoc.Util.encode/1","ref":"NLdoc.Util.html#encode/1"},{"type":"function","doc":"iex> NLdoc.Util.encode(%{a: 1, b: 2})\n    %{a: 1, b: 2}\n    iex> NLdoc.Util.encode([1, 2, 3])\n    [1, 2, 3]\n    iex> NLdoc.Util.encode([a: 1, b: 2])\n    %{a: 1, b: 2}\n    iex> NLdoc.Util.encode({:parameterized, {Ecto.Enum, %{data: [1, 2, 3]}}})\n    [:parameterized, \"Ecto.Enum\"]\n    iex> NLdoc.Util.encode({\"error\", [type: {\"error\", \"details\"}, validation: :inclusion]})\n    [\"error\", %{type: [\"error\", \"details\"], validation: :inclusion}]","title":"Examples - NLdoc.Util.encode/1","ref":"NLdoc.Util.html#encode/1-examples"},{"type":"function","doc":"Asserts that an OK tuple is `{:ok, value}` and returns the value.\nRaises the error if the tuple is `{:error, error}`.","title":"NLdoc.Util.ok!/1","ref":"NLdoc.Util.html#ok!/1"},{"type":"function","doc":"iex> NLdoc.Util.ok!({:ok, 1})\n    1\n    iex> NLdoc.Util.ok!(:ok)\n    :ok\n\n    iex> NLdoc.Util.ok!({:error, \"error\"})\n    ** (RuntimeError) error\n\n    iex> NLdoc.Util.ok!({:error, %File.Error{path: \"file\", reason: :enoent}})\n    ** (File.Error) could not  \"file\": no such file or directory\n\n    iex> NLdoc.Util.ok!({:error, %{foo: \"bar\"}})\n    ** (RuntimeError) %{foo: \"bar\"}","title":"Examples - NLdoc.Util.ok!/1","ref":"NLdoc.Util.html#ok!/1-examples"},{"type":"function","doc":"Tests an OK-tuple, returning the value if the tuple is `{:ok, value}` or returning whatever is\nreturned by calling the given function with the error if the tuple is `{:error, error}`.","title":"NLdoc.Util.ok_else/2","ref":"NLdoc.Util.html#ok_else/2"},{"type":"function","doc":"iex> NLdoc.Util.ok_else({:ok, 1}, 2)\n      1\n      iex> NLdoc.Util.ok_else({:error, \"error\"}, fn error -> String.upcase(error) end)\n      \"ERROR\"\n      iex> NLdoc.Util.ok_else(:ok, :abc)\n      :ok","title":"Examples - NLdoc.Util.ok_else/2","ref":"NLdoc.Util.html#ok_else/2-examples"},{"type":"function","doc":"Returns true if the two lists have the same values, regardless of order.","title":"NLdoc.Util.same_values/2","ref":"NLdoc.Util.html#same_values/2"},{"type":"function","doc":"iex> NLdoc.Util.same_values([], [])\n    true\n    iex> NLdoc.Util.same_values([1, 2, 3], [1, 2, 3])\n    true\n    iex> NLdoc.Util.same_values([1, 2, 3], [3, 2, 1])\n    true\n    iex> NLdoc.Util.same_values([1, 2, 3], [1, 2, 4])\n    false\n    iex> NLdoc.Util.same_values([1, 2, 3], [1, 2, 3, 4])\n    false","title":"Examples - NLdoc.Util.same_values/2","ref":"NLdoc.Util.html#same_values/2-examples"},{"type":"module","doc":"`NLdoc.Util.Recase` implements utility functions for converting the keys of maps and structs\nto camelCase or snake_case.","title":"NLdoc.Util.Recase","ref":"NLdoc.Util.Recase.html"},{"type":"function","doc":"Converts a map or struct to a map with different keys.","title":"NLdoc.Util.Recase.convert_keys/3","ref":"NLdoc.Util.Recase.html#convert_keys/3"},{"type":"function","doc":"iex> NLdoc.Util.Recase.convert_keys(\n    ...>   %{\n    ...>     HelloWorld: 1,\n    ...>     abc_123: %URI{scheme: \"http\", host: \"example.com\"},\n    ...>     fooBar: [%{Hello: 123}]\n    ...>   },\n    ...>   &Recase.to_pascal/1\n    ...> )\n    %{\n      Abc123: %{\n        Authority: nil,\n        Fragment: nil,\n        Host: \"example.com\",\n        Path: nil,\n        Port: nil,\n        Query: nil,\n        Scheme: \"http\",\n        Userinfo: nil\n      },\n      HelloWorld: 1,\n      FooBar: [%{Hello: 123}]\n    }","title":"Examples - NLdoc.Util.Recase.convert_keys/3","ref":"NLdoc.Util.Recase.html#convert_keys/3-examples"},{"type":"type","doc":"","title":"NLdoc.Util.Recase.key/0","ref":"NLdoc.Util.Recase.html#t:key/0"},{"type":"type","doc":"","title":"NLdoc.Util.Recase.opt/0","ref":"NLdoc.Util.Recase.html#t:opt/0"},{"type":"function","doc":"Converts a string or atom to camelCase and converts a map or a struct to a map with camelCase keys (recursively).\n\nUnlike `Recase.to_camel/1`, this function splits the key on every dot and then calls Recase, allowing keys like\n`\"image.source_url\"` to be camelCased as `\"image.sourceUrl\"`.","title":"NLdoc.Util.Recase.to_camel/2","ref":"NLdoc.Util.Recase.html#to_camel/2"},{"type":"function","doc":"For strings and atoms:\n\n    iex> NLdoc.Util.Recase.to_camel(\"example_test\")\n    \"exampleTest\"\n    iex> NLdoc.Util.Recase.to_camel(:example_test)\n    :exampleTest\n    iex> NLdoc.Util.Recase.to_camel(\"example_test.nested.item_one\")\n    \"exampleTest.nested.itemOne\"\n    iex> NLdoc.Util.Recase.to_camel(:\"example_test.nested.item_one\")\n    :\"exampleTest.nested.itemOne\"\n\nFor maps and structs:\n\n    iex> NLdoc.Util.Recase.to_camel(\n    ...>   %{ HelloWorld: 1, abc_123: %URI{scheme: \"http\", host: \"example.com\"} }\n    ...> )\n    %{\n      helloWorld: 1,\n      abc123: %{\n        authority: nil,\n        fragment: nil,\n        host: \"example.com\",\n        path: nil,\n        port: nil,\n        query: nil,\n        scheme: \"http\",\n        userinfo: nil\n      }\n    }\n\n    iex> %{my_list: [key_word: {:error, :message}, other_word: {:ok, nil}], \"descriptors[0].alt_text\": \"test\" }\n    ...>  |> NLdoc.Util.Recase.to_camel()\n    %{\n      myList: [keyWord: {:error, :message}, otherWord: {:ok, nil}],\n      \"descriptors[0].altText\": \"test\"\n    }\n\nDateTime objects are passed through unchanged.\n\n    iex> now = DateTime.utc_now()\n    iex> now == now |> NLdoc.Util.Recase.to_camel()\n    true","title":"Examples - NLdoc.Util.Recase.to_camel/2","ref":"NLdoc.Util.Recase.html#to_camel/2-examples"},{"type":"function","doc":"Converts a string or atom to snake_case and converts a map or a struct to a map with snake_case keys (recursively).\n\nUnlike `Recase.to_snake/1`, this function splits the key on every dot and then calls Recase, allowing keys like\n`\"image.sourceUrl\"` to be snake_cased as `\"image.source_url\"`.","title":"NLdoc.Util.Recase.to_snake/2","ref":"NLdoc.Util.Recase.html#to_snake/2"},{"type":"function","doc":"For strings and atoms:\n\n    iex> NLdoc.Util.Recase.to_snake(\"exampleTest\")\n    \"example_test\"\n    iex> NLdoc.Util.Recase.to_snake(:exampleTest)\n    :example_test\n    iex> NLdoc.Util.Recase.to_snake(\"exampleTest.nested.itemOne\")\n    \"example_test.nested.item_one\"\n    iex> NLdoc.Util.Recase.to_snake(:\"exampleTest.nested.itemOne\")\n    :\"example_test.nested.item_one\"\n\nFor maps and structs:\n\n    iex> NLdoc.Util.Recase.to_snake(\n    ...>   %{ HelloWorld: 1, abc_123: %URI{scheme: \"http\", host: \"example.com\"} }\n    ...> )\n    %{\n      hello_world: 1,\n      abc_123: %{\n        authority: nil,\n        fragment: nil,\n        host: \"example.com\",\n        path: nil,\n        port: nil,\n        query: nil,\n        scheme: \"http\",\n        userinfo: nil\n      }\n    }\n\n    iex> %{myList: [KeyWord: {:error, :message}, otherWord: {:ok, nil}], \"descriptors[0].altText\": \"test\" }\n    ...>  |> NLdoc.Util.Recase.to_snake()\n    %{\n      my_list: [key_word: {:error, :message}, other_word: {:ok, nil}],\n      \"descriptors[0].alt_text\": \"test\"\n    }\n\nDateTime objects are passed through unchanged.\n\n    iex> now = DateTime.utc_now()\n    iex> now == now |> NLdoc.Util.Recase.to_snake()\n    true","title":"Examples - NLdoc.Util.Recase.to_snake/2","ref":"NLdoc.Util.Recase.html#to_snake/2-examples"},{"type":"module","doc":"This module defines a macro for defining a struct that captures the state during a conversion.","title":"NLdoc.Util.State","ref":"NLdoc.Util.State.html"},{"type":"module","doc":"```ex\nmodule State do\n  use NLdoc.Util.State\n\n  schema do\n    field :example, String.t(), default: \"Hello\"\n    field :foo, integer() | nil # Infers has default `nil`\n    field :bar, [String.t() | integer()] # Infers has default `[]`\n  end\nend\n```","title":"Usage - NLdoc.Util.State","ref":"NLdoc.Util.State.html#module-usage"},{"type":"function","doc":"","title":"NLdoc.Util.State.field/2","ref":"NLdoc.Util.State.html#field/2"},{"type":"function","doc":"","title":"NLdoc.Util.State.field/3","ref":"NLdoc.Util.State.html#field/3"},{"type":"macro","doc":"","title":"NLdoc.Util.State.schema/1","ref":"NLdoc.Util.State.html#schema/1"},{"type":"module","doc":"Checks if is uri or path","title":"NLdoc.Util.StringFormat","ref":"NLdoc.Util.StringFormat.html"},{"type":"function","doc":"Converts a map or struct to a map with different keys.","title":"NLdoc.Util.StringFormat.uri?/1","ref":"NLdoc.Util.StringFormat.html#uri?/1"},{"type":"function","doc":"With string values:\n\n    iex> NLdoc.Util.StringFormat.uri?(\"https://example.com/123\")\n    true\n    iex> NLdoc.Util.StringFormat.uri?(\"media/image.png\")\n    false\n    iex> NLdoc.Util.StringFormat.uri?(\"ftp://example.com/123\")\n    true\n\nOr with parsed URI's:\n\n    iex> NLdoc.Util.StringFormat.uri?(%URI{path: \"media/image.png\"})\n    false\n    iex> NLdoc.Util.StringFormat.uri?(%URI{scheme: \"http\", host: \"example.com\", path: \"/media/image.png\"})\n    true","title":"Examples - NLdoc.Util.StringFormat.uri?/1","ref":"NLdoc.Util.StringFormat.html#uri?/1-examples"},{"type":"extras","doc":"# NLdoc.Test\n\n**TODO: Add description**","title":"NLdoc.Test","ref":"readme.html"},{"type":"extras","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `nldoc_test` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:nldoc_test, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","title":"Installation - NLdoc.Test","ref":"readme.html#installation"},{"type":"extras","doc":"# Changelog\n\n## [1.0.7](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.6...1.0.7) (2025-02-11)","title":"Changelog","ref":"changelog.html"},{"type":"extras","doc":"* **deps:** update dependency ex_doc to v0.37.1 ([3353bbb](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/3353bbb4c95a265300ef57b525e875b5e1480319))\n\n## [1.0.6](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.5...1.0.6) (2025-01-27)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **deps:** update dependency excoveralls to v0.18.5 ([b170ea0](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/b170ea0a2d5ab8552df4e70b5585526c36632896))\n\n## [1.0.5](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.4...1.0.5) (2025-01-23)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **docs:** enrich documentation ([810261e](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/810261ef5c2f7559f1d845f8f08ca334de9c109e))\n\n## [1.0.4](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.3...1.0.4) (2025-01-22)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* **docs:** main ([78a647a](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/78a647a9c9308459c029c7fa0ea34a4bd8244e1f))\n\n## [1.0.3](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.2...1.0.3) (2025-01-22)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* ex_doc ([98693b9](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/98693b9eb72f2fce1c6a053edb3c8b62b94997ff))\n\n## [1.0.2](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.1...1.0.2) (2025-01-22)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* correct meta to docs ([fc05cab](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/fc05cab167d0c4d43bd48a52fbf6e8a50d79465e))\n\n## [1.0.1](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/compare/1.0.0...1.0.1) (2025-01-22)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* metadata about project ([8e51453](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/8e5145355c3e6eb875841af2bfd88da5bf8903c9))\n\n# 1.0.0 (2025-01-22)","title":"Bug Fixes - Changelog","ref":"changelog.html#bug-fixes"},{"type":"extras","doc":"* finalize wrapping logic in package ([b9ea26f](https://gitlab.com/toegang-voor-iedereen/backend/lib/nldoc_util/commit/b9ea26fcbf96ac0b2cc295224008961f8806c4c6))","title":"Features - Changelog","ref":"changelog.html#features"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}